huey, a little task queue — huey 0.2.2 documentation

### Navigation

- index
- modules |
- next |
- huey 0.2.2 documentation »

# huey, a little task queue

a lightweight alternative.

- written in python
- support for django
- no deps outside stdlib, except redis (or roll your own backend)

named after my cat

Contents:

- Installing
  - Using git
- Getting Started
  - General guide
  - Django integration
- Understanding how commands are imported
  - Suggested organization of code
- Troubleshooting and Common Pitfalls
- Huey’s API
  - Function decorators and helpers
  - The Invoker and AsyncData classes
  - Configuration
  - Queues and DataStores
- Django API
  - Function decorators and helpers
  - Configuration

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- huey 0.2.2 documentation »